@@ -28,6 +28,7 @@ import os
 import json
 import time
 import logging
+from six.moves.urllib.parse import urljoin
 from contextlib import contextmanager
 from slapos.slap.slap import ConnectionError
 from . import logger, log_formatter
@@ -189,6 +190,7 @@ shared = true
     finally:
       logger.propagate = True
       logger.removeHandler(handler)
+      handler.close()
 
   def checkRevision(self, test_result, node_test_suite):
     if node_test_suite.revision == test_result.revision:
@@ -341,8 +343,8 @@ shared = true
               self.cleanUp() # XXX not a good place to do that
               continue
             with self.suiteLog(node_test_suite) as suite_log_folder_name:
-              test_result.reportStatus('LOG url', "%s/%s" % (
-                config.get('httpd_url'), suite_log_folder_name), '')
+              test_result.reportStatus(
+                  'LOG url', urljoin(config['log_frontend_url'], suite_log_folder_name), '')
               git_gc_auto = self.checkRevision(test_result, node_test_suite)
               node_test_suite.edit(test_result=test_result)
               # get cluster configuration for this test suite, this is needed to
